@@ -250,7 +250,13 @@ cloudwatch = {
 	},
 	'ASG': {
 		'dimension': 'AutoScalingGroupName',
-		'namespace': 'AWS/AutoScaling'
+		'namespace': 'AWS/AutoScaling',
+		'namespace_by_metric_name': {
+			'StatusCheckFailed': 'AWS/EC2',
+			'CPUUtilization': 'AWS/EC2',
+			'swap_used_percent': 'CWAgent',
+			'disk_used_percent': 'CWAgent'
+		}
 	},
 	'CloudFront': {
 		'dimension': 'DistributionId',
@@ -924,6 +930,7 @@ ami_types = [
     'ubuntu_16_snap', # Instances created from Ubuntu Server 16.04 AMIs identified with 20180627, SSM Agent is pre-installed using Snap packages
     'ubuntu_17',
     'ubuntu_18',
+	'ubuntu_18_cis',
     'ubuntu_19',
     'ubuntu_20',
     'microsoft',
